aboutsummaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorMarcoFalke <falke.marco@gmail.com>2018-01-23 13:58:53 -0500
committerMarcoFalke <falke.marco@gmail.com>2018-01-23 13:55:40 -0500
commitffffb10a9f12b43d4716048ebfd7203bd79e59f3 (patch)
tree7a581d08025df36927f8fe450608196d0c706b4a /test
parentb7450cdbd89a1c862f4d4d8bf093f8a0b5448f9c (diff)
downloadbitcoin-ffffb10a9f12b43d4716048ebfd7203bd79e59f3.tar.xz
qa: Rename cli.args to cli.options
That is the name in bitcoin-cli -help
Diffstat (limited to 'test')
-rwxr-xr-xtest/functional/test_framework/test_node.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/test/functional/test_framework/test_node.py b/test/functional/test_framework/test_node.py
index 589a8f3969..d9dd945bdd 100755
--- a/test/functional/test_framework/test_node.py
+++ b/test/functional/test_framework/test_node.py
@@ -213,16 +213,16 @@ class TestNodeCLI():
"""Interface to bitcoin-cli for an individual node"""
def __init__(self, binary, datadir):
- self.args = []
+ self.options = []
self.binary = binary
self.datadir = datadir
self.input = None
self.log = logging.getLogger('TestFramework.bitcoincli')
- def __call__(self, *args, input=None):
- # TestNodeCLI is callable with bitcoin-cli command-line args
+ def __call__(self, *options, input=None):
+ # TestNodeCLI is callable with bitcoin-cli command-line options
cli = TestNodeCLI(self.binary, self.datadir)
- cli.args = [str(arg) for arg in args]
+ cli.options = [str(o) for o in options]
cli.input = input
return cli
@@ -244,7 +244,7 @@ class TestNodeCLI():
pos_args = [str(arg) for arg in args]
named_args = [str(key) + "=" + str(value) for (key, value) in kwargs.items()]
assert not (pos_args and named_args), "Cannot use positional arguments and named arguments in the same bitcoin-cli call"
- p_args = [self.binary, "-datadir=" + self.datadir] + self.args
+ p_args = [self.binary, "-datadir=" + self.datadir] + self.options
if named_args:
p_args += ["-named"]
p_args += [command] + pos_args + named_args